Learn R Programming

Evacluster (version 0.1.0)

predict.hierarchicalCluster: hierarchicalCluster prediction function

Description

This function predicts the labels of the cluster for new data based on cluster labels of the training set.

Usage

# S3 method for hierarchicalCluster
predict(object, ...)

Arguments

object

A returned object of hierarchicalCluster function

New samples set

Value

A list of cluster labels